aioworkers-orm
==============

.. image:: https://travis-ci.org/aioworkers/aioworkers-orm.svg?branch=master
  :target: https://travis-ci.org/aioworkers/aioworkers-orm

.. image:: https://img.shields.io/pypi/pyversions/aioworkers-orm.svg
  :target: https://pypi.python.org/pypi/aioworkers-orm
  :alt: Python versions

.. image:: https://img.shields.io/pypi/v/aioworkers-orm.svg
  :target: https://pypi.python.org/pypi/aioworkers-orm


Development
-----------

Install dev requirements:


.. code-block:: shell

    pipenv install --dev --skip-lock


Run tests:

.. code-block:: shell

    pytest
